Codat.Accounting.ProfitAndLoss (codat v1.0.0)

Copy Markdown View Source

Read profit and loss (income statement) financial statements.

Summary

Functions

Returns the profit and loss statement for a company.

Functions

get(client_or_company_id, company_id_or_opts \\ [], opts \\ [])

@spec get(Codat.Client.t() | String.t(), String.t() | keyword(), keyword()) ::
  {:ok, map()} | {:error, Codat.Error.t()}

Returns the profit and loss statement for a company.

Options

  • :period_length — length of each reporting period in months (default: 1)
  • :periods_to_compare — number of periods to return (default: 12)
  • :start_month — ISO8601 month string (e.g. "2024-01")