Manage bank feed data connections.
Bank feed connections require fetching a short-lived token that your front-end uses to render the account authorization UI.
Summary
Functions
Returns bank feed connection information including the authorization URL.
Functions
@spec get_info(Codat.Client.t() | String.t(), String.t(), String.t() | keyword()) :: {:ok, map()} | {:error, Codat.Error.t()}
Returns bank feed connection information including the authorization URL.
Example
{:ok, info} = Codat.BankFeeds.Connections.get_info(client, company_id, conn_id)
info["linkUrl"] # => "https://link.codat.io/..."