Codat.BillPay.Connections (codat v1.0.0)

Copy Markdown View Source

Manage Bill Pay-specific data connections.

Handles connection initialization and the authorization flow specific to the Bill Pay solution.

Summary

Functions

Returns the Bill Pay connection information for a company/connection pair.

Functions

get_info(client_or_company_id, company_or_conn_id, conn_or_opts \\ [])

@spec get_info(Codat.Client.t() | String.t(), String.t(), String.t() | keyword()) ::
  {:ok, map()} | {:error, Codat.Error.t()}

Returns the Bill Pay connection information for a company/connection pair.

Example

{:ok, info} = Codat.BillPay.Connections.get_info(client, company_id, conn_id)