Telemetry integration for the Codat client.
Events
[:codat, :request, :start]— before each HTTP request[:codat, :request, :stop]— after each HTTP request[:codat, :request, :exception]— on unhandled exceptions[:codat, :retry, :attempt]— on each retry[:codat, :rate_limit, :hit]— on 429 responses
Summary
Functions
Attaches a default structured logger to all Codat telemetry events.
Detaches the default logger.
Returns all telemetry event names emitted by this library.
Functions
@spec attach_default_logger(Logger.level()) :: :ok | {:error, :already_exists}
Attaches a default structured logger to all Codat telemetry events.
@spec detach_default_logger() :: :ok | {:error, :not_found}
Detaches the default logger.
@spec events() :: [[atom(), ...], ...]
Returns all telemetry event names emitted by this library.